@@ -42,10 +42,13 @@ class Gateway():
         
         self.configserial()
 
+        try:
+            loop = asyncio.get_running_loop()
+        except RuntimeError:  # no event loop running:
+            loop = asyncio.new_event_loop()
 
         if discover:
             _LOGGER.info("Discovering devices")
-            loop = asyncio.new_event_loop()
             asyncio.set_event_loop(loop)
             result = loop.run_until_complete(self.discover())
 
@@ -337,17 +340,17 @@ class Gateway():
         command = CommeoServiceGetVersion()
         return await command.execute(self)
 
-    def getGatewayFirmwareVersion(self):
+    async def getGatewayFirmwareVersion(self):
         command = self.getVersionG()
         if hasattr(command, "version"):
             return command.version
 
-    def getGatewaySerial(self):
+    async def getGatewaySerial(self):
         command = self.getVersionG()
         if hasattr(command, "serial"):
             return command.serial
 
-    def getGatewaySpec(self):
+    async def getGatewaySpec(self):
         command = self.getVersionG()
         if hasattr(command, "spec"):
             return command.spec
